function [I_s, T_s, yAo_s, Fin_s, TAB] = ParetoFunction(nvars, lb, ub)

%% PARAMETER AND CONSTANT VALUES

V     = 2.0E-4;  % m3,           Reactor Volume
R     = 8.314;   % J  ./ mol ./ K, Gas constant
I_o   = 1.6;     % mW ./ m2,      Reference light intensity
P     = 101325;  % Pa

P_1   = 1.503;   % m3 ./ mol ./ s, Adsorption constant regression variable
P_2   = 1.5E-5;  % m3 ./ mol ./ s, Adsorption constant regression variable
P_3   = 32430;   % J  ./ mol,     Adsorption constant regression variable

k_D1  = 1E13;    % 1  ./ s,   Desorption first pre-expo factor
k_D2  = 2.05;    % 1  ./ s,   Desorption second pre-expo factor

E_AD1 = 113100;  % J  ./ mol, Desorption first energy barrier
E_AD2 = 20920;   % J  ./ mol, Desorption second energy barrier

kr    = 0.24;    % 1  ./ s,   Reaction pre-expo factor. Range = 0.001 - 0.24, dependant on light coverage. Assuming max
E_AR  = 8480;    % J  ./ mol, Reaction energy barrier

ntot  = 0.0537;           % mol ./ m3, Total adsorption sites per unit volume of reactor

%% Function


[xx, fval] = ss_optimization_1(nvars, lb, ub);

  
yAo = xx(:,1) ;
Fin = xx(:,2) ;
I   = xx(:,3) ;


%% System
% Need to account for two phase, when increasing yAo must increase inlet
% and reactor temp
%Antoine Coefficients, from Yaws and Yang Handbook
Aa = 7.37789; Ba = 1563.28; Ca = 247.07;
Pr = P ./ 133.322; % mmHg    
pA  = Pr .* yAo; % mmHg, partial presure of formic acid

To   = Ba ./ (Aa - log10(pA)) - Ca + 273.15;
%T_in   = x(4) .* 273.15 ; %293.15 ;
T = To ;

kads =   P_1 + P_2 .* exp (  P_3 ./ R ./ T);
kdes =   k_D1 .* exp (- E_AD1 ./ R ./ T) + k_D2 .* exp (- E_AD2  ./ R ./ T);
nr   =   ntot .* exp (- E_AR  ./ R ./ T) .* (I ./ I_o).^ 0.3; 

MF_A_in = Fin .*yAo.*P./R./To ;

%% STEADY-STATE VALUES COMPUTATION

yA =  -(Fin.*R.*T.*kdes.*ntot - (Fin.^2.*R.^2.*T.^2.*kr.^2.*nr.^2 + 2.*Fin.^2.*R.^2.*T.^2.*kdes.*kr.*nr.*ntot + Fin.^2.*R.^2.*T.^2.*kdes.^2.*ntot.^2 + 2.*Fin.*R.^2.*T.*To.*V.*kads.*kr.^2.*nr.^2.*ntot + 2.*Fin.*R.^2.*T.*To.*V.*kads.*kdes.*kr.*nr.*ntot.^2 + R.^2.*To.^2.*V.^2.*kads.^2.*kr.^2.*nr.^2.*ntot.^2 ...
      + 2.*Fin.^2.*P.*R.*T.*kads.*kr.*nr.*ntot.*yAo + 4.*Fin.*R.^2.*T.*To.*V.*kads.*kr.^2.*nr.^2.*ntot.*yAo + 2.*Fin.^2.*P.*R.*T.*kads.*kdes.*ntot.^2.*yAo + 4.*Fin.*R.^2.*T.*To.*V.*kads.*kdes.*kr.*nr.*ntot.^2.*yAo - 2.*Fin.*P.*R.*To.*V.*kads.^2.*kr.*nr.*ntot.^2.*yAo + Fin.^2.*P.^2.*kads.^2.*ntot.^2.*yAo.^2).^(1./2) + Fin.*R.*T.*kr.*nr - Fin.*P.*kads.*ntot.*yAo + R.*To.*V.*kads.*kr.*nr.*ntot)./(2.*(Fin.*P.*kads.*ntot + R.*To.*V.*kads.*kr.*nr.*ntot));

thetaA = (P.*kads.*yA)./(R.*T.*(kdes + (kr.*nr)./ntot + (P.*kads.*yA)./(R.*T)));
Fout   = V.*(T./To .* Fin./V - kads .*ntot .* (1-thetaA) .* yA + R.* T./P .* kdes .* thetaA .* ntot + 2.*R.*T./P .* kr   .* nr    .* thetaA   );
yC     = (R.*T.*V.*kr.*nr.*thetaA)./(Fout.*P); 
yH     = (R.*T.*V.*kr.*nr.*thetaA)./(Fout.*P);
yN     = 1-yA-yC-yH;
          

MF_A_s  = Fout.*yA.*P./R./T ;
Conv_A  = ( MF_A_in - MF_A_s ) ./ MF_A_in .* 100 ;

MassF_P_s  = Fout.*P./R./T.*(yC*44.01+yH*2.01568);

%% Checking zeroes
eq1_ss = T./To  .* Fin./V .* yAo - Fout./V .* yA - (kads .* (1-thetaA) .* ntot .* yA) + R.*T./P .* (kdes .* thetaA .* ntot);
eq2_ss = R.*T./P .* (kr   .* nr    .* thetaA)          - Fout./V .* yC;
eq3_ss = R.*T./P .* (kr   .* nr    .* thetaA)          - Fout./V .* yH;
eq4_ss = (kads .* (1-thetaA) .* yA) .* P./R./T   - (kdes .* thetaA) - (kr   .* nr    .* thetaA)./ntot;

%% Plots
figure
plot(MF_A_in,MF_A_s,'p')
xlabel('Inlet acid molar flow rate, mol./s')
ylabel('Outlet acid molar flow rate, mol./s')

figure
plot(MF_A_in,Conv_A,'p')
xlabel('Inlet acid molar flow rate, mol./s')
ylabel('Conversion of acid, %')

%% Table

pstn    = find(Conv_A>50 & Conv_A<70);
I_s     = I(pstn);
T_s     = T(pstn);
yAo_s   = yAo(pstn);
Fin_s   = Fin(pstn);
Conv_As = Conv_A(pstn);
ProdMas = MassF_P_s(pstn);
TAB     = sortrows(table(Conv_As, ProdMas, I_s, T_s, yAo_s, Fin_s));

end