function [xx, fval] = ss_optimization_1(nvars, lb, ub) 
%% PARAMETER AND CONSTANT VALUES

V     = 2.0E-4;  % m3,           Reactor Volume
R     = 8.314;   % J  / mol / K, Gas constant
I_o   = 1.6;     % mW / m2,      Reference light intensity
P     = 101325;  % Pa

P_1   = 1.503;   % m3 / mol / s, Adsorption constant regression variable
P_2   = 1.5E-5;  % m3 / mol / s, Adsorption constant regression variable
P_3   = 32430;   % J  / mol,     Adsorption constant regression variable

k_D1  = 1E13;    % 1  / s,   Desorption first pre-expo factor
k_D2  = 2.05;    % 1  / s,   Desorption second pre-expo factor

E_AD1 = 113100;  % J  / mol, Desorption first energy barrier
E_AD2 = 20920;   % J  / mol, Desorption second energy barrier

kr    = 0.24;    % 1  / s,   Reaction pre-expo factor. Range = 0.001 - 0.24, dependant on light coverage. Assuming max
E_AR  = 8480;    % J  / mol, Reaction energy barrier

ntot  = 0.0537;           % mol / m3, Total adsorption sites per unit volume of reactor



%% OPTIMIZATION OF FORCING AMPLITUDES FOR THE SIMULTANEOUS CHANGE

%       yAo               Fin               I          T
A = [] ;
b = [] ;

options1 = optimoptions('gamultiobj', 'Display', 'Iter','PopulationSize', 1000, 'MaxGenerations', 50000, 'FunctionTolerance', 1e-3,'PlotFcn',@gaplotpareto,'UseParallel',true);

[x,fval,exitflag] = gamultiobj(@(x)objfun(x),nvars,[],[],[],[],lb,ub,@(x)constraints(x),options1);

xx      = x ;
xx(:,1) = x(:,1) / 10 ;
xx(:,2) = x(:,2) * 1.2e-7 ;
xx(:,3) = x(:,3) ;
%xx(:,4) = x(:,4) * 273.15 ;

function of = objfun(x)

yAos = x(1) / 10 ;
Fins  = x(2) * 1.2e-7 ;
Is    = x(3) ;

% Need to account for two phase, when increasing yAo must increase inlet
% and reactor temp
%Antoine Coefficients, from Yaws and Yang Handbook
Aa = 7.37789; Ba = 1563.28; Ca = 247.07;
Pr = P ./ 133.322; % mmHg    
pA  = Pr .* yAos; % mmHg, partial presure of formic acid

Tos   = Ba ./ (Aa - log10(pA)) - Ca + 273.15;
%T_in   = x(4) * 273.15 ; %293.15 ;
Ts = Tos ;

kads =   P_1 + P_2 .* exp (  P_3 ./ R ./ Ts);
kdes =   k_D1 .* exp (- E_AD1 ./ R ./ Ts) + k_D2 .* exp (- E_AD2  ./ R ./ Ts);
nr   =   ntot .* exp (- E_AR  ./ R ./ Ts) .* (Is ./ I_o).^ 0.3; 

MF_A_in = Fins *yAos*P/R/Tos ;

%% STEADY-STATE VALUES COMPUTATION

yAs     =  -(Fins*R*Ts*kdes*ntot - (Fins^2*R^2*Ts^2*kr^2*nr^2 + 2*Fins^2*R^2*Ts^2*kdes*kr*nr*ntot + Fins^2*R^2*Ts^2*kdes^2*ntot^2 + 2*Fins*R^2*Ts*Tos*V*kads*kr^2*nr^2*ntot + 2*Fins*R^2*Ts*Tos*V*kads*kdes*kr*nr*ntot^2 + R^2*Tos^2*V^2*kads^2*kr^2*nr^2*ntot^2 ...
            + 2*Fins^2*P*R*Ts*kads*kr*nr*ntot*yAos + 4*Fins*R^2*Ts*Tos*V*kads*kr^2*nr^2*ntot*yAos + 2*Fins^2*P*R*Ts*kads*kdes*ntot^2*yAos + 4*Fins*R^2*Ts*Tos*V*kads*kdes*kr*nr*ntot^2*yAos - 2*Fins*P*R*Tos*V*kads^2*kr*nr*ntot^2*yAos + Fins^2*P^2*kads^2*ntot^2*yAos^2)^(1/2) + Fins*R*Ts*kr*nr - Fins*P*kads*ntot*yAos + R*Tos*V*kads*kr*nr*ntot)/(2*(Fins*P*kads*ntot + R*Tos*V*kads*kr*nr*ntot));
 

thetaAs = (P*kads*yAs)/(R*Ts*(kdes + (kr*nr)/ntot + (P*kads*yAs)/(R*Ts)));
FoutSS  = V*(Ts./Tos .* Fins./V - kads .*ntot * (1-thetaAs) .* yAs + R* Ts/P * kdes .* thetaAs * ntot + 2*R.*Ts/P * kr   .* nr    .* thetaAs   );
yHs     = (R*Ts*V*kr*nr*thetaAs)/(FoutSS*P);
yCs     = (R*Ts*V*kr*nr*thetaAs)/(FoutSS*P);
yNs     = 1-yAs-yCs-yHs;

MF_A_s = FoutSS*yAs*P/R/Ts ;

Conv_A = ( MF_A_in - MF_A_s ) / MF_A_in * 100 ;

of(1) = - MF_A_in ;
of(2) = - Conv_A ;

end

%% CONSTRAINTS

function  [c,ceq] = constraints(x)
    
yAos = x(1) / 10 ;
Fins = x(2) * 1.2e-7 ;
Is   = x(3) ;

% Need to account for two phase, when increasing yAo must increase inlet
% and reactor temp
%Antoine Coefficients, from Yaws and Yang Handbook
Aa = 7.37789; Ba = 1563.28; Ca = 247.07;
Pr = P ./ 133.322; % mmHg    
pA  = Pr .* yAos; % mmHg, partial presure of formic acid
Tos   = Ba ./ (Aa - log10(pA)) - Ca + 273.15 ;
Ts = Tos ;

kads =   P_1 + P_2 .* exp (  P_3 ./ R ./ Ts);
kdes =   k_D1 .* exp (- E_AD1 ./ R ./ Ts) + k_D2 .* exp (- E_AD2  ./ R ./ Ts);
nr   =   ntot .* exp (- E_AR  ./ R ./ Ts) .* (Is ./ I_o).^ 0.3; 

MF_A_in = Fins *yAos*P/R/Tos ;

%% STEADY-STATE VALUES COMPUTATION

yAs     =  -(Fins*R*Ts*kdes*ntot - (Fins^2*R^2*Ts^2*kr^2*nr^2 + 2*Fins^2*R^2*Ts^2*kdes*kr*nr*ntot + Fins^2*R^2*Ts^2*kdes^2*ntot^2 + 2*Fins*R^2*Ts*Tos*V*kads*kr^2*nr^2*ntot + 2*Fins*R^2*Ts*Tos*V*kads*kdes*kr*nr*ntot^2 + R^2*Tos^2*V^2*kads^2*kr^2*nr^2*ntot^2 ...
            + 2*Fins^2*P*R*Ts*kads*kr*nr*ntot*yAos + 4*Fins*R^2*Ts*Tos*V*kads*kr^2*nr^2*ntot*yAos + 2*Fins^2*P*R*Ts*kads*kdes*ntot^2*yAos + 4*Fins*R^2*Ts*Tos*V*kads*kdes*kr*nr*ntot^2*yAos - 2*Fins*P*R*Tos*V*kads^2*kr*nr*ntot^2*yAos + Fins^2*P^2*kads^2*ntot^2*yAos^2)^(1/2) + Fins*R*Ts*kr*nr - Fins*P*kads*ntot*yAos + R*Tos*V*kads*kr*nr*ntot)/(2*(Fins*P*kads*ntot + R*Tos*V*kads*kr*nr*ntot));
 

thetaAs = (P*kads*yAs)/(R*Ts*(kdes + (kr*nr)/ntot + (P*kads*yAs)/(R*Ts)));
FoutSS   = V*(Ts./Tos .* Fins./V - kads .*ntot * (1-thetaAs) .* yAs + R* Ts/P * kdes .* thetaAs * ntot + 2*R.*Ts/P * kr   .* nr    .* thetaAs   );
yHs     = (R*Ts*V*kr*nr*thetaAs)/(FoutSS*P);
yCs     = (R*Ts*V*kr*nr*thetaAs)/(FoutSS*P);
yNs     = 1-yAs-yCs-yHs;

MF_A_s = FoutSS*yAs*P/R/Ts ;

Conv_A = ( MF_A_in - MF_A_s ) / MF_A_in * 100 ;
    
c=[Conv_A-100; -yAs; -Conv_A]; %always better to set 2 rather than ceq
ceq=[];

end


end